@@ -55,18 +55,15 @@ use syn::{parse_macro_input, Attribute, AttributeArgs, DeriveInput, MetaNameValu
 ///    //
 ///    #[serde(default)]
 ///    #[field_attrs(
-///        widget = "inputImage",
-///        label = "Photo",
-///        value = r#"{
-///                "path":"./media/no_avatar.png",
-///                "url":"/media/no_avatar.png"
-///            }"#,
-///        placeholder = "Upload your photo",
-///        accept = "image/jpeg,image/png",
-///        hint = "Image in JPEG or PNG format",
-///        thumbnails = r#"[["xs",150],["sm",300]]"#
+///        widget = "inputSlug",
+///        label = "Slug",
+///        unique = true,
+///        readonly = true,
+///        is_hide = true,
+///        hint = "To create a human readable url",
+///        slug_sources = r#"["username"]"#
 ///    )]
-///    pub photo: Option<String>,
+///    pub slug: Option<String>,
 ///    //
 ///    #[serde(default)]
 ///    #[field_attrs(
@@ -177,9 +174,6 @@ fn impl_create_model(args: &Vec<NestedMeta>, ast: &mut DeriveInput) -> TokenStre
         ..Default::default()
     };
     let mut trans_map_widgets: TransMapWidgets = Default::default();
-    // <field_name, (widget_type, value)>
-    let mut map_default_values: std::collections::HashMap<String, (String, String)> =
-        std::collections::HashMap::new();
     let mut add_trait_custom_valid = quote! {impl AdditionalValidation for #model_name {}};
 
     // Get Model attributes.
@@ -293,7 +287,7 @@ fn impl_create_model(args: &Vec<NestedMeta>, ast: &mut DeriveInput) -> TokenStre
             })
             .unwrap_or_else(|err| panic!("{}", err.to_string()));
             let new_field = new_field.named.first().unwrap().to_owned();
-            &fields.push(new_field);
+            fields.push(new_field);
 
             // Get the number of fields.
             trans_meta.fields_count = fields.len();
@@ -537,9 +531,8 @@ fn impl_create_model(args: &Vec<NestedMeta>, ast: &mut DeriveInput) -> TokenStre
                     field_name,
                 )
             }
-        }
         // Validation the `slug_sources` parameter for widgets of the `Slug` type.
-        if widget.widget.contains("Slug") {
+        } else if widget.widget.contains("Slug") {
             if !widget.value.is_empty() {
                 panic!(
                     "Model: `{}` > Field: `{}` > Parameter: `value` : \
@@ -567,22 +560,19 @@ fn impl_create_model(args: &Vec<NestedMeta>, ast: &mut DeriveInput) -> TokenStre
                     }
                 }
             }
-        }
         // File fields must not be ignored.
-        match widget.widget.as_str() {
-            "inputFile" | "inputImage" if trans_meta.ignore_fields.contains(field_name) => {
-                panic!(
-                    "Model: `{}` > Field: `{}` : \
+        } else if (widget.widget == "inputFile" || widget.widget == "inputImage")
+            && trans_meta.ignore_fields.contains(field_name)
+        {
+            panic!(
+                "Model: `{}` > Field: `{}` : \
                      Ignored fields are incompatible with fields of type `file`.",
-                    model_name.to_string(),
-                    field_name,
-                )
-            }
-            _ => {}
-        }
+                model_name.to_string(),
+                field_name,
+            )
         // For widgets of the `select` type,
         // the default value must correspond to one of the proposed options.
-        if widget.widget.contains("select") {
+        } else if widget.widget.contains("select") {
             if !widget.value.is_empty()
                 && widget
                     .options
@@ -598,13 +588,12 @@ fn impl_create_model(args: &Vec<NestedMeta>, ast: &mut DeriveInput) -> TokenStre
                     field_name,
                 )
             }
-        }
         // For widgets with support for u32 numbers, parameter min = 0
-        if widget.widget.contains("U32") {
+        } else if widget.widget.contains("U32") {
             widget.min = 0_usize.to_string();
         }
         // Add default values in the map.
-        map_default_values.insert(
+        trans_meta.map_default_values.insert(
             field_name.clone(),
             (
                 widget.widget.clone(),
@@ -616,7 +605,6 @@ fn impl_create_model(args: &Vec<NestedMeta>, ast: &mut DeriveInput) -> TokenStre
             ),
         );
     }
-    trans_meta.map_default_values = map_default_values;
 
     // trans_meta to Json-line.
     // ---------------------------------------------------------------------------------------------
